Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(694)

Unified Diff: chrome/browser/resources/print_preview/search/destination_list_item.js

Issue 588713002: Compile print_preview, part 3: reduce down to 185 errors (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@I_print_preview_2
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/print_preview/search/destination_list_item.js
diff --git a/chrome/browser/resources/print_preview/search/destination_list_item.js b/chrome/browser/resources/print_preview/search/destination_list_item.js
index 9f843ee0288191b2626bbc01bcff4b65a18c8575..5b26f43827d91255b5211ef58ff09f93d6a1d30c 100644
--- a/chrome/browser/resources/print_preview/search/destination_list_item.js
+++ b/chrome/browser/resources/print_preview/search/destination_list_item.js
@@ -11,11 +11,11 @@ cr.define('print_preview', function() {
* events to.
* @param {!print_preview.Destination} destination Destination data object to
* render.
* @param {RegExp} query Active filter query.
* @constructor
* @extends {print_preview.Component}
*/
- function DestinationListItem(eventTarget, destination, query) {
+ function DestinationListItem(eventTarget, destination, opt_query) {
print_preview.Component.call(this);
/**
@@ -34,10 +34,10 @@ cr.define('print_preview', function() {
/**
* Active filter query text.
- * @type {RegExp}
+ * @type {(RegExp|undefined)}
* @private
*/
- this.query_ = query;
+ this.query_ = opt_query;
Aleksey Shlyapnikov 2014/09/22 22:00:40 Can we have it this way: @type {RegExp} and this.q
Vitaly Pavlenko 2014/09/22 22:33:11 Done, with {?RegExp}.
/**
@@ -11,11 +11,11 @@ cr.define('print_preview', function() {
* @param {!print_preview.Destination} destination Destination data object to
* render.
- * @param {RegExp} query Active filter query.
+ * @param {RegExp=} opt_query Active filter query.
* @constructor
* @extends {print_preview.Component}
* FedEx terms-of-service widget or {@code null} if this list item does not

Powered by Google App Engine
This is Rietveld 408576698